Class: Google::Cloud::DataQnA::V1alpha::DataQuery
- Inherits:
-
Object
- Object
- Google::Cloud::DataQnA::V1alpha::DataQuery
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataqna/v1alpha/question.rb
Overview
Representation of the data query for the backend.
This is provided for informational purposes only. Clients should not use
it to send it to the backend directly, but rather use the execute RPC
to trigger the execution. Using the execute RPC is needed in order to
track the state of a question and report on it correctly to the data
administrators.
Instance Attribute Summary collapse
-
#sql ⇒ ::String
The generated SQL query to be sent to the backend.